function [sigA2,tau]=avar(Y,tau0,k0)
% Calcul de la variance d'Allan
%
% Entrées:
% Y    : signal
% tau0 : l'intervalle de temps entre deux données
% k0   : le vecteur des multiples de tau0 pour lesquels on calcule la variance
%
% Sorties:
% sigA2 : la variance d'Allant (vecteur)
% tau   : le vecteurs des échelles de temps auxquelles on a calculé la
%         variance d'Allant
N=length(Y);
for j=1:length(k0)
    k=k0(j);
    tau(j)=k*tau0;
    Xbar=zeros(1,N-k+1);
    for i=1:N-k+1
        Yi=Y(i:i+k-1);
        Xbar(i)=mean(Yi);
    end
    Xbart=Xbar(k+1:N-k+1);
    Xbart_k=Xbar(1:N-2*k+1);
    sigA2(j)=sum((Xbart-Xbart_k).^2)/(2*length(Xbart));
    end
end
